@@ -49,8 +49,7 @@ from samtranslator.model.role_utils import construct_role_for_resource
 
 
 class SamFunction(SamResourceMacro):
-    """SAM function macro.
-    """
+    """SAM function macro."""
 
     resource_type = "AWS::Serverless::Function"
     property_types = {
@@ -697,8 +696,7 @@ class SamFunction(SamResourceMacro):
 
 
 class SamApi(SamResourceMacro):
-    """SAM rest API macro.
-    """
+    """SAM rest API macro."""
 
     resource_type = "AWS::Serverless::Api"
     property_types = {
@@ -810,8 +808,7 @@ class SamApi(SamResourceMacro):
 
 
 class SamHttpApi(SamResourceMacro):
-    """SAM rest API macro.
-    """
+    """SAM rest API macro."""
 
     resource_type = "AWS::Serverless::HttpApi"
     property_types = {
@@ -833,6 +830,7 @@ class SamHttpApi(SamResourceMacro):
         "RouteSettings": PropertyType(False, is_type(dict)),
         "Domain": PropertyType(False, is_type(dict)),
         "FailOnWarnings": PropertyType(False, is_type(bool)),
+        "DisableExecuteApiEndpoint": PropertyType(False, is_type(bool)),
     }
 
     referable_properties = {
@@ -872,9 +870,16 @@ class SamHttpApi(SamResourceMacro):
             passthrough_resource_attributes=self.get_passthrough_resource_attributes(),
             domain=self.Domain,
             fail_on_warnings=self.FailOnWarnings,
+            disable_execute_api_endpoint=self.DisableExecuteApiEndpoint,
         )
 
-        (http_api, stage, domain, basepath_mapping, route53,) = api_generator.to_cloudformation()
+        (
+            http_api,
+            stage,
+            domain,
+            basepath_mapping,
+            route53,
+        ) = api_generator.to_cloudformation()
 
         resources.append(http_api)
         if domain:
@@ -892,8 +897,7 @@ class SamHttpApi(SamResourceMacro):
 
 
 class SamSimpleTable(SamResourceMacro):
-    """SAM simple table macro.
-    """
+    """SAM simple table macro."""
 
     resource_type = "AWS::Serverless::SimpleTable"
     property_types = {
@@ -952,8 +956,7 @@ class SamSimpleTable(SamResourceMacro):
 
 
 class SamApplication(SamResourceMacro):
-    """SAM application macro.
-    """
+    """SAM application macro."""
 
     APPLICATION_ID_KEY = "ApplicationId"
     SEMANTIC_VERSION_KEY = "SemanticVersion"
@@ -971,14 +974,12 @@ class SamApplication(SamResourceMacro):
     }
 
     def to_cloudformation(self, **kwargs):
-        """Returns the stack with the proper parameters for this application
-        """
+        """Returns the stack with the proper parameters for this application"""
         nested_stack = self._construct_nested_stack()
         return [nested_stack]
 
     def _construct_nested_stack(self):
-        """Constructs a AWS::CloudFormation::Stack resource
-        """
+        """Constructs a AWS::CloudFormation::Stack resource"""
         nested_stack = NestedStack(
             self.logical_id, depends_on=self.depends_on, attributes=self.get_passthrough_resource_attributes()
         )
@@ -992,8 +993,7 @@ class SamApplication(SamResourceMacro):
         return nested_stack
 
     def _get_application_tags(self):
-        """Adds tags to the stack if this resource is using the serverless app repo
-        """
+        """Adds tags to the stack if this resource is using the serverless app repo"""
         application_tags = {}
         if isinstance(self.Location, dict):
             if self.APPLICATION_ID_KEY in self.Location.keys() and self.Location[self.APPLICATION_ID_KEY] is not None:
@@ -1007,8 +1007,7 @@ class SamApplication(SamResourceMacro):
 
 
 class SamLayerVersion(SamResourceMacro):
-    """ SAM Layer macro
-    """
+    """SAM Layer macro"""
 
     resource_type = "AWS::Serverless::LayerVersion"
     property_types = {
@@ -1106,8 +1105,7 @@ class SamLayerVersion(SamResourceMacro):
 
 
 class SamStateMachine(SamResourceMacro):
-    """SAM state machine macro.
-    """
+    """SAM state machine macro."""
 
     resource_type = "AWS::Serverless::StateMachine"
     property_types = {
@@ -1123,7 +1121,9 @@ class SamStateMachine(SamResourceMacro):
         "Policies": PropertyType(False, one_of(is_str(), list_of(one_of(is_str(), is_type(dict), is_type(dict))))),
         "Tracing": PropertyType(False, is_type(dict)),
     }
-    event_resolver = ResourceTypeResolver(samtranslator.model.stepfunctions.events,)
+    event_resolver = ResourceTypeResolver(
+        samtranslator.model.stepfunctions.events,
+    )
 
     def to_cloudformation(self, **kwargs):
         managed_policy_map = kwargs.get("managed_policy_map", {})
